==> unleash-0.0.5.tar.gz: test/unleash_settings_test.dart <==
import 'package:test/test.dart';
import 'package:unleash/src/unleash_settings.dart';

import 'test_utils.dart';

void main() {
  test('UnleashSettings.toHeader', () {
    final settings = UnleashSettings(
      appName: 'appname',
      instanceId: 'instanceid',
      unleashApi: Uri.parse('https://example.org/api'),
    );

    expect(settings.toHeaders(), <String, String>{
      'UNLEASH-APPNAME': 'appname',
      'UNLEASH-INSTANCEID': 'instanceid',
    });
  });

  test('test assertions', () {
    expect(() {
      UnleashSettings(
        appName: null,
        instanceId: 'instanceid',
        unleashApi: Uri.parse('https://example.org/api'),
      );
    }, throwsAssertionError);

    expect(() {
      UnleashSettings(
        appName: 'appname',
        instanceId: null,
        unleashApi: Uri.parse('https://example.org/api'),
      );
    }, throwsAssertionError);

    expect(() {
      UnleashSettings(
        appName: 'appname',
        instanceId: 'instanceid',
        unleashApi: null,
      );
    }, throwsAssertionError);
  });

  test('test urls', () {
    var settings = UnleashSettings(
      unleashApi: Uri.parse('https://unleash.herokuapp.com/api'),
      instanceId: 'instance',
      appName: 'appname',
    );
    expect(settings.featureUrl,
        'https://unleash.herokuapp.com/api/client/features');
    expect(settings.registerUrl,
        'https://unleash.herokuapp.com/api/client/register');

    settings = UnleashSettings(
      unleashApi: Uri.parse('https://unleash.herokuapp.com/api/'),
      instanceId: 'instance',
      appName: 'appname',
    );
    expect(settings.featureUrl,
        'https://unleash.herokuapp.com/api/client/features');
    expect(settings.registerUrl,
        'https://unleash.herokuapp.com/api/client/register');
  });
}

==> unleash-0.4.1.tar.gz: test/unleash_settings_test.dart <==
import 'package:test/test.dart';
import 'package:unleash/src/unleash_settings.dart';

void main() {
  test('UnleashSettings.toHeader', () {
    final settings = UnleashSettings(
      appName: 'appname',
      instanceId: 'instanceid',
      unleashApi: Uri.parse('https://example.org/api'),
      apiToken: '',
    );

    expect(settings.toHeaders(), <String, String>{
      'UNLEASH-APPNAME': 'appname',
      'UNLEASH-INSTANCEID': 'instanceid',
      'Authorization': '',
    });
  });

  test('UnleashSettings.toHeader with custome headers', () {
    final settings = UnleashSettings(
        appName: 'appname',
        instanceId: 'instanceid',
        unleashApi: Uri.parse('https://example.org/api'),
        apiToken: '123',
        customHeaders: {'X-CUSTOM': 'WORLD'});

    expect(settings.toHeaders(), <String, String>{
      'UNLEASH-APPNAME': 'appname',
      'UNLEASH-INSTANCEID': 'instanceid',
      'Authorization': '123',
      'X-CUSTOM': 'WORLD',
    });
  });

  test('test urls', () {
    var settings = UnleashSettings(
      unleashApi: Uri.parse('https://unleash.herokuapp.com/api'),
      instanceId: 'instance',
      appName: 'appname',
      apiToken: '',
    );
    expect(
      settings.featureUrl,
      Uri.parse('https://unleash.herokuapp.com/api/client/features'),
    );
    expect(
      settings.registerUrl,
      Uri.parse('https://unleash.herokuapp.com/api/client/register'),
    );

    settings = UnleashSettings(
      unleashApi: Uri.parse('https://unleash.herokuapp.com/api/'),
      instanceId: 'instance',
      appName: 'appname',
      apiToken: '',
    );
    expect(
      settings.featureUrl,
      Uri.parse('https://unleash.herokuapp.com/api/client/features'),
    );
    expect(
      settings.registerUrl,
      Uri.parse('https://unleash.herokuapp.com/api/client/register'),
    );
  });
}
